@@ -615,13 +615,13 @@ class _ProtoBuilder:
         # `_load_message` method.
         answer: Dict[str, wrappers.Field] = collections.OrderedDict()
         for i, field_pb in enumerate(field_pbs):
-            is_oneof = oneofs and field_pb.oneof_index > 0
+            is_oneof = oneofs and field_pb.HasField('oneof_index')
             oneof_name = nth(
                 (oneofs or {}).keys(),
                 field_pb.oneof_index
             ) if is_oneof else None
 
-            answer[field_pb.name] = wrappers.Field(
+            field = wrappers.Field(
                 field_pb=field_pb,
                 enum=self.api_enums.get(field_pb.type_name.lstrip('.')),
                 message=self.api_messages.get(field_pb.type_name.lstrip('.')),
@@ -631,6 +631,7 @@ class _ProtoBuilder:
                 ),
                 oneof=oneof_name,
             )
+            answer[field.name] = field
 
         # Done; return the answer.
         return answer
